GCSerialInterface

Struct GCSerialInterface 

#[repr(transparent)]
pub struct GCSerialInterface(sGCSerialInterface);
Zero-cost abstraction over Serial interface configuration from C ABI.

This struct wraps the C ABI struct and provides safe Rust accessors.

Tuple Fields

0: sGCSerialInterface

Implementations



impl GCSerialInterface

pub fn interface<'a>(&'a self) -> Cow<'a, str>

Get the OS interface path (e.g., “/dev/ttyS0”, “/dev/ttyM0”)

Returns the interface path as a string slice, or None if the C string is invalid.

pub fn baud_rate(&self) -> u32

Get the baud rate (e.g., 9600, 115200)

pub fn parity(&self) -> Result<Parity, GCPluginABIError>

Get the parity setting

pub fn stop_bits(&self) -> Result<StopBits, GCPluginABIError>

Get the number of stop bits

pub fn data_bits(&self) -> Result<DataBits, GCPluginABIError>

Get the number of data bits