Struct GCSerialInterface
#[repr(transparent)]pub struct GCSerialInterface(sGCSerialInterface);Expand description
Zero-cost abstraction over Serial interface configuration from C ABI.
This struct wraps the C ABI struct and provides safe Rust accessors.
Tuple Fields
0: sGCSerialInterfaceImplementations
impl GCSerialInterface
impl GCSerialInterface
pub fn interface<'a>(&'a self) -> Cow<'a, str>
pub fn interface<'a>(&'a self) -> Cow<'a, str>
Get the OS interface path (e.g., “/dev/ttyS0”, “/dev/ttyM0”)
Returns the interface path as a string slice, or None if the C string is invalid.
pub fn parity(&self) -> Result<Parity, GCPluginABIError>
pub fn parity(&self) -> Result<Parity, GCPluginABIError>
Get the parity setting
pub fn stop_bits(&self) -> Result<StopBits, GCPluginABIError>
pub fn stop_bits(&self) -> Result<StopBits, GCPluginABIError>
Get the number of stop bits
pub fn data_bits(&self) -> Result<DataBits, GCPluginABIError>
pub fn data_bits(&self) -> Result<DataBits, GCPluginABIError>
Get the number of data bits